@@ -54,7 +54,6 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -129,7 +128,7 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class SendAction extends RTAction  {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(SendAction.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SendAction.class);
 
     private final JSONProtocolHandler protocolHandler;
     private final StateManager stateManager;
@@ -144,9 +143,7 @@ public class SendAction extends RTAction  {
         ID id = constructID(request, session);
         if(!stateManager.isConnected(id)) {
             RealtimeException stateMissingException = RealtimeExceptionCodes.STATE_MISSING.create();
-            if(LOG.isDebugEnabled()) {
-                LOG.debug(stateMissingException.getMessage(), stateMissingException);
-            }
+            LOG.debug("", stateMissingException);
             Map<String, Object> errorMap = getErrorMap(stateMissingException, session);
             return new AJAXRequestResult(errorMap, "native");
         }
@@ -163,7 +160,7 @@ public class SendAction extends RTAction  {
                     objects.add(array.getJSONObject(i));
                 } catch (JSONException e) {
                     RealtimeException malformedBodyException = RealtimeExceptionCodes.STANZA_BAD_REQUEST.create(e.getMessage());
-                    LOG.error(malformedBodyException.getMessage(), malformedBodyException);
+                    LOG.error("", malformedBodyException);
                     Map<String, Object> errorAndStanzasMap = getErrorAndStanzasMap(malformedBodyException, session, clientState);
                     return new AJAXRequestResult(errorAndStanzasMap, "native");
                 }
@@ -172,11 +169,11 @@ public class SendAction extends RTAction  {
             objects = Arrays.asList((JSONObject) data);
         } else {
             RealtimeException malformedBodyException = RealtimeExceptionCodes.STANZA_BAD_REQUEST.create("Request body must be JSON");
-            LOG.error(malformedBodyException.getMessage(), malformedBodyException);
+            LOG.error("", malformedBodyException);
             Map<String, Object> errorAndStanzasMap = getErrorAndStanzasMap(malformedBodyException, session, clientState);
             return new AJAXRequestResult(errorAndStanzasMap, "native");
         }
-        LOG.debug("Messages arrived in SendAction: " + objects.toString());
+        LOG.debug("Messages arrived in SendAction: {}", objects);
 
 
         //handle incoming messages
@@ -184,15 +181,13 @@ public class SendAction extends RTAction  {
         protocolHandler.handleIncomingMessages(id, session, stateEntry, objects, acknowledgements);
 
         //add resulting acks to response
-        Map<String, Object> resultMap = new HashMap<String, Object>();
+        final Map<String, Object> resultMap = new HashMap<String, Object>();
         resultMap.put(ACKS, acknowledgements);
 
         //additionally check for Stanza that are addressed to the client and add them to the response
         List<JSONObject> stanzas = pollStanzas(clientState);
         resultMap.put(STANZAS, stanzas);
-        if(LOG.isDebugEnabled()) {
-            LOG.debug(RTResultFormatter.format(resultMap));
-        }
+        LOG.debug("{}", new Object() { @Override public String toString() { return RTResultFormatter.format(resultMap);}});
         return new AJAXRequestResult(resultMap, "native");
     }
 
