@@ -52,6 +52,8 @@ package com.openexchange.realtime.json.impl;
 import java.util.ArrayList;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
+import com.openexchange.realtime.cleanup.GlobalRealtimeCleanup;
+import com.openexchange.realtime.json.osgi.JSONServiceRegistry;
 import com.openexchange.realtime.json.protocol.RTClientState;
 import com.openexchange.realtime.json.protocol.StanzaTransmitter;
 import com.openexchange.realtime.packet.ID;
@@ -59,13 +61,13 @@ import com.openexchange.realtime.packet.IDEventHandler;
 
 /**
  * The {@link StateManager} manages the state of connected clients.
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
 public class StateManager {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.loggerFor(StateManager.class);
-    
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(StateManager.class);
+
     private final ConcurrentHashMap<ID, RTClientState> states = new ConcurrentHashMap<ID, RTClientState>();
 
     private final ConcurrentHashMap<ID, StanzaTransmitter> transmitters = new ConcurrentHashMap<ID, StanzaTransmitter>();
@@ -102,7 +104,7 @@ public class StateManager {
 
     /**
      * Associate a {@linkStanza Transmitter} with an {@link ID}
-     * 
+     *
      * @param id The ID
      * @param transmitter The transmitter that can be used to send messages to the associated ID
      */
@@ -112,7 +114,7 @@ public class StateManager {
 
     /**
      * Remove a {@linkStanza Transmitter} <-> {@link ID} association
-     * 
+     *
      * @param id The ID
      * @param transmitter The transmitter
      */
@@ -121,17 +123,17 @@ public class StateManager {
     }
 
     /**
-     * Times out states that haven't been touched in more than thirty minutes. Additionally this triggers a refresh of IDs that aren't 
+     * Times out states that haven't been touched in more than thirty minutes. Additionally this triggers a refresh of IDs that aren't
      * timed out, yet.
-     * 
+     *
      * @param timestamp - The timestamp to compare the lastSeen value to
      */
     public void timeOutStaleStates(long timestamp) {
         for (RTClientState state : new ArrayList<RTClientState>(states.values())) {
             if (state.isTimedOut(timestamp)) {
-                if(LOG.isDebugEnabled()) {
-                    LOG.debug("State for id " + state.getId() + " is timed out. Last seen: " + state.getLastSeen());
-                }
+                LOG.debug("State for id {} is timed out. Last seen: {}", state.getId(), state.getLastSeen());
+                GlobalRealtimeCleanup globalRealtimeCleanup = JSONServiceRegistry.getInstance().getService(GlobalRealtimeCleanup.class);
+                globalRealtimeCleanup.cleanForId(state.getId());
                 state.getId().dispose(this, null);
             } else {
                 state.getId().trigger(ID.Events.REFRESH, this);
@@ -140,8 +142,8 @@ public class StateManager {
     }
 
     /**
-     * Checks if we already have a state associated with this client 
-     * 
+     * Checks if we already have a state associated with this client
+     *
      * @param id the {@link ID} representing the client
      * @return true if we already have a state associated with this client
      */
