@@ -57,6 +57,8 @@ import com.openexchange.conversion.simple.SimpleConverter;
 import com.openexchange.conversion.simple.SimplePayloadConverter;
 import com.openexchange.management.ManagementService;
 import com.openexchange.realtime.Channel;
+import com.openexchange.realtime.cleanup.GlobalRealtimeCleanup;
+import com.openexchange.realtime.cleanup.RealtimeJanitor;
 import com.openexchange.realtime.directory.ResourceDirectory;
 import com.openexchange.realtime.dispatch.MessageDispatcher;
 import com.openexchange.realtime.exception.RealtimeException;
@@ -64,6 +66,7 @@ import com.openexchange.realtime.handle.StanzaQueueService;
 import com.openexchange.realtime.json.actions.RealtimeActions;
 import com.openexchange.realtime.json.impl.JSONChannel;
 import com.openexchange.realtime.json.impl.RTJSONHandler;
+import com.openexchange.realtime.json.management.ManagementHouseKeeper;
 import com.openexchange.realtime.json.payload.converter.JSONToRealtimeExceptionConverter;
 import com.openexchange.realtime.json.payload.converter.JSONToStackTraceElementConverter;
 import com.openexchange.realtime.json.payload.converter.JSONToThrowableConverter;
@@ -76,7 +79,6 @@ import com.openexchange.realtime.json.payload.converter.primitive.JSONToStringCo
 import com.openexchange.realtime.json.payload.converter.primitive.StringToJSONConverter;
 import com.openexchange.realtime.json.presence.converter.JSONToPresenceStateConverter;
 import com.openexchange.realtime.json.presence.converter.PresenceStateToJSONConverter;
-import com.openexchange.realtime.json.management.ManagementHouseKeeper;
 import com.openexchange.realtime.packet.Presence;
 import com.openexchange.realtime.packet.PresenceState;
 import com.openexchange.realtime.packet.Stanza;
@@ -95,7 +97,7 @@ public class RTJSONActivator extends AJAXModuleActivator {
         return new Class<?>[] {
             ConfigurationService.class, SessiondService.class, MessageDispatcher.class, SimpleConverter.class,
             ResourceDirectory.class, StanzaQueueService.class, PayloadTreeConverter.class, CapabilityService.class, TimerService.class,
-            ThreadPoolService.class, ManagementService.class};
+            ThreadPoolService.class, ManagementService.class, GlobalRealtimeCleanup.class};
     }
 
     @Override
@@ -106,6 +108,7 @@ public class RTJSONActivator extends AJAXModuleActivator {
 
         handler = new RTJSONHandler();
         registerService(Channel.class, new JSONChannel(handler));
+        registerService(RealtimeJanitor.class, handler.getGate());
 
         /*
          * Register the package specific payload converters. The SimpleConverterActivator listens for registrations of new
